package cn.com.infosec.asn1.esf;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AttributeCertificate;

public class SignerAttribute extends ASN1Encodable {
   private ASN1Sequence claimedAttributes;
   private AttributeCertificate certifiedAttributes;

   public static SignerAttribute getInstance(Object o) {
      if (o != null && !(o instanceof SignerAttribute)) {
         if (o instanceof ASN1Sequence) {
            return new SignerAttribute(o);
         } else {
            throw new IllegalArgumentException("unknown object in 'SignerAttribute' factory: " + o.getClass().getName() + ".");
         }
      } else {
         return (SignerAttribute)o;
      }
   }

   private SignerAttribute(Object o) {
      DERTaggedObject o1;
      if ((o1 = (DERTaggedObject)((ASN1Sequence)o).getObjectAt(0)).getTagNo() == 0) {
         this.claimedAttributes = ASN1Sequence.getInstance(o1, true);
      } else {
         if (o1.getTagNo() != 1) {
            throw new IllegalArgumentException("illegal tag.");
         }

         this.certifiedAttributes = AttributeCertificate.getInstance(o1);
      }

   }

   public SignerAttribute(ASN1Sequence claimedAttributes) {
      this.claimedAttributes = claimedAttributes;
   }

   public SignerAttribute(AttributeCertificate certifiedAttributes) {
      this.certifiedAttributes = certifiedAttributes;
   }

   public ASN1Sequence getClaimedAttributes() {
      return this.claimedAttributes;
   }

   public AttributeCertificate getCertifiedAttributes() {
      return this.certifiedAttributes;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      ASN1Sequence var2;
      if ((var2 = this.claimedAttributes) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(0, var2);
         var1.add(var3);
      } else {
         DERTaggedObject var4;
         var4 = new DERTaggedObject.<init>(1, this.certifiedAttributes);
         var1.add(var4);
      }

      return new DERSequence(var1);
   }
}
